from typing import Any, List, Literal, TypedDict

from .FHIR_code import FHIR_code
from .FHIR_Element import FHIR_Element
from .FHIR_string import FHIR_string

# The CodeSystem resource is used to declare the existence of and describe a code system or code system supplement and its key properties, and optionally define a part or all of its content.
FHIR_CodeSystem_Filter = TypedDict(
    "FHIR_CodeSystem_Filter",
    {
        # Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
        "id": FHIR_string,
        # May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance  applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
        "extension": List[Any],
        # May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element's descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.Modifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself).
        "modifierExtension": List[Any],
        # The code that identifies this filter when it is used as a filter in [[[ValueSet]]].compose.include.filter.
        "code": FHIR_code,
        # Extensions for code
        "_code": FHIR_Element,
        # A description of how or why the filter is used.
        "description": FHIR_string,
        # Extensions for description
        "_description": FHIR_Element,
        # A list of operators that can be used with the filter.
        "operator": List[FHIR_code],
        # Extensions for operator
        "_operator": List[FHIR_Element],
        # A description of what the value for the filter should be.
        "value": FHIR_string,
        # Extensions for value
        "_value": FHIR_Element,
    },
    total=False,
)
